.. _bids_langloc_dataset:

BIDS language localizer
=======================

.. warning::

    This dataset is a duplicate of :ref:`language_localizer_dataset`.
    It will be deprecated in Nilearn 0.13.0.

    Use :func:`nilearn.datasets.fetch_language_localizer_demo_dataset` instead.

Notes
-----

More info at: https://osf.io/u5mzy
